from .AbstractProcess import *
from .AbstractProcessApplicationService import *
from .ProcessId import *
from .ProcessTimeOut import *
from .TimeConstrainedProcessTracker import *
from .TimeConstrainedProcessTrackerRepository import *
from .timeout_event_factory import *



from .AbstractIdentity import *
from .AbstractValueObject import *
from .File import *
from .FullName import *
from .ImageURL import *
from .RegexValue import *
from .URL import *
from .UUID import *



from .AbstractDomainEventDict import *
from .AggregateRoot import *
from .DomainEvent import *
from .DomainEventPublisher import *
from .DomainEventSubscriber import *
from .DomainService import *
from .Entity import *
from .exceptions import *
from .IdentifiedDomainObject import *
from .mixins import *
from .utils import *
from .validator import *
from .value_object import *



from .adapters import *
from .application import *
from .domain import *
from .exceptions import *
from .fp import *
from .logic import *
from .media import *
from .process import *
from .serializer import *
from .types import *
from .utils import *



from sqlalchemy.ext.asyncio.session import AsyncSession

from dino_seedwork_be.adapters.IRepository import IRepository
from dino_seedwork_be.adapters.persistance.sql.DBSessionUser import \
    DBSessionUser

__all__ = ["AlchemyRepository"]


class AlchemyRepository(DBSessionUser[AsyncSession], IRepository):
    pass



from typing import List, TypeVar

ElementType = TypeVar("ElementType")

__all__ = ["shallow_compare_list"]


def shallow_compare_list(a1: List, a2: List):
    return not any((item not in a2) for item in a1)
